==> fastack_cache-1.1.0-py3-none-any.whl: fastack_cache/decorators.py <==
from functools import wraps
from inspect import iscoroutinefunction
from types import MethodType
from typing import Callable

from fastack_cache.backends.base import BaseCacheBackend
from fastack_cache.helpers import get_cache_backend, get_request_object, run_async
from fastack_cache.key import get_cache_key


def auto_connect(method: MethodType):
    if iscoroutinefunction(method):

        @wraps(method)
        async def wrapper(*args, **kwargs):
            self: BaseCacheBackend = args[0]
            if not self.client:
                await self.connect()
            return await method(*args, **kwargs)

    else:

        @wraps(method)
        def wrapper(*args, **kwargs):
            self: BaseCacheBackend = args[0]
            if not self.client:
                self.connect()
            return method(*args, **kwargs)

    return wrapper


def cached(
    timeout: int = 15, *, key: Callable = get_cache_key, cache: str = "default"
) -> Callable:
    """
    Decorator to cache the result of a function.
    """

    assert callable(key), "key must be callable"

    def decorator(func: Callable) -> Callable:
        if iscoroutinefunction(func):

            @wraps(func)
            async def wrapper(*args, **kwargs):
                request = get_request_object(kwargs, func.__name__)
                cache_backend = get_cache_backend(request, cache)
                cache_key = key(request)
                cache_get = cache_backend.get
                if iscoroutinefunction(cache_get):
                    value = await cache_get(cache_key)
                else:
                    value = cache_get(cache_key)

                if value is None:
                    value = await func(*args, **kwargs)
                    cache_set = cache_backend.set
                    if iscoroutinefunction(cache_set):
                        await cache_set(cache_key, value, timeout)
                    else:
                        cache_set(cache_key, value, timeout)

                return value

        else:

            @wraps(func)
            def wrapper(*args, **kwargs):
                request = get_request_object(kwargs, func.__name__)
                cache_backend = get_cache_backend(request, cache)
                cache_key = key(request)
                cache_get = cache_backend.get
                if iscoroutinefunction(cache_get):
                    value = run_async(cache_get, cache_key)
                else:
                    value = cache_get(cache_key)

                if value is None:
                    value = func(*args, **kwargs)
                    cache_set = cache_backend.set
                    if iscoroutinefunction(cache_set):
                        run_async(cache_set, cache_key, value, timeout)
                    else:
                        cache_set(cache_key, value, timeout)

                return value

        return wrapper

    return decorator

==> fastack_cache-1.2.0-py3-none-any.whl: fastack_cache/decorators.py <==
from asyncio import iscoroutinefunction
from functools import wraps
from types import MethodType
from typing import Callable

from fastapi import Request

from fastack_cache.backends.base import BaseCacheBackend
from fastack_cache.helpers import get_cache_backend, get_request_object, run_sync
from fastack_cache.key import get_cache_key


def auto_connect(method: MethodType):
    if iscoroutinefunction(method):

        @wraps(method)
        async def wrapper(*args, **kwargs):
            self: BaseCacheBackend = args[0]
            if not self.client:
                await self.connect()
            return await method(*args, **kwargs)

    else:

        @wraps(method)
        def wrapper(*args, **kwargs):
            self: BaseCacheBackend = args[0]
            if not self.client:
                self.connect()
            return method(*args, **kwargs)

    return wrapper


def cached(
    timeout: int = 15,
    *,
    key: Callable[[Request], str] = get_cache_key,
    cache: str = "default"
) -> Callable:
    """
    Decorator to cache the result of a function.
    """

    assert callable(key), "key must be callable"

    def decorator(func: Callable) -> Callable:
        if iscoroutinefunction(func):

            @wraps(func)
            async def wrapper(*args, **kwargs):
                request = get_request_object(kwargs)
                cache_backend = get_cache_backend(request, cache)
                cache_key = key(request)
                cache_get = cache_backend.get
                if iscoroutinefunction(cache_get):
                    value = await cache_get(cache_key)
                else:
                    value = cache_get(cache_key)

                if value is None:
                    value = await func(*args, **kwargs)
                    cache_set = cache_backend.set
                    if iscoroutinefunction(cache_set):
                        await cache_set(cache_key, value, timeout)
                    else:
                        cache_set(cache_key, value, timeout)

                return value

        else:

            @wraps(func)
            def wrapper(*args, **kwargs):
                request = get_request_object(kwargs)
                cache_backend = get_cache_backend(request, cache)
                cache_key = key(request)
                cache_get = cache_backend.get
                if iscoroutinefunction(cache_get):
                    value = run_sync(cache_get, cache_key)
                else:
                    value = cache_get(cache_key)

                if value is None:
                    value = func(*args, **kwargs)
                    cache_set = cache_backend.set
                    if iscoroutinefunction(cache_set):
                        run_sync(cache_set, cache_key, value, timeout)
                    else:
                        cache_set(cache_key, value, timeout)

                return value

        return wrapper

    return decorator
